function A=randdiag(N,d,varargin)
% -- fc_amat.random.randdiag(N,d)
% -- fc_amat.random.randdiag(N,d,key,value,...)
%      Returns a N-by-d-by-d amat object with random diagonal matrices elements
%      uniformly distributed on the open interval (a,b)=(0,1) and zeros 
%      elsewhere.
%
%      Some optional key/value pairs arguments are available with keys:
%        - 'complex', if value is true the amat object is complex and the
%                     imaginary parts of the diagonal matrices elements are 
%                     also uniformly distributed on the open interval (0, 1).
%                     (default false i.e real amat object)
%        - 'class',   value can be 'single' or 'double' (default).
%        - 'nc',      number of columns of matrices (default: d)
%        - 'k',       offset of k diagonals above or below the main diagonal; 
%                     above for positive k and below for negative k.
%        - 'a', to set a (lower bound of the interval) value (0 by default).
%        - 'b', to set b (upper bound of the interval) value (1 by default).
%
%      See also: fc_amat.random.randtriu, fc_amat.random.randtril
%                class amat
%
  p = inputParser;
  p.addParamValue('nc',d,@isscalar); % number of columns
  p.addParamValue('k',0,@isscalar); % diag number
  p.addParamValue('class','double',@(x) ismember(lower(x),{'single','double'})); 
  p.addParamValue('complex',false,@islogical);
  p.addParamValue('a',0,@isscalar); 
  p.addParamValue('b',1,@isscalar); 
  
  p.parse(varargin{:});
  nc=p.Results.nc;k=p.Results.k;
  a=p.Results.a;b=p.Results.b;
  classname=p.Results.class;
  assert( a < b , 'a must be less than b!')
  h=b-a;
  R=p.Results;
  if R.complex
    A=complex(amat(N,d,d,R.class));
    gen=@() complex(a+h*rand(N,1,R.class),a+h*rand(N,1,R.class));
  else
    A=amat(N,d,d,R.class);
    gen=@() a+h*rand(N,1,R.class);
  end
  for i=1:min(d,R.nc)
    j=i+R.k;
    if ( j>=1 && j<=R.nc ), A(i,j)=gen(); end
  end
end
